function love.load()

  -- Set up world
  love.physics.setMeter(65)
  world = love.physics.newWorld(0, 9.81*65, true)
 
  -- Window dimensions
  windim = {height = love.graphics.getHeight(), width = love.graphics.getWidth()}
 
  map = {5,4,3,2,1,0,0,0,1,1,1,0,0,0,1,1,1,2,2,2,1,1,1,2,2,2,2,1,1,2,2,2,3,3,3,3,1,1,1,1,0,0,0}
  
  --grpoints = { 100 * #map,windim.height-20, 0, windim.height-20 }
  grpoints = {}
  for idx = 1, #map do
    table.insert(grpoints, (idx * 300) - 5600)
    table.insert(grpoints,  windim.height - map[idx]*100 - 200)
  end
 
  objects = {}
  
  -- The world boundary
  objects.boundary = {}
  objects.boundary.shape = love.physics.newChainShape(false, -5000, -500, -5000, 800, 10000, 800, 10000, -500)
  objects.boundary.body = love.physics.newBody(world, 0, 800)
  objects.boundary.fixture = love.physics.newFixture(objects.boundary.body, objects.boundary.shape)
  
  objects.motorspeed = 0
 
  -- Ground/Floor
  objects.ground = {}
  objects.ground.body = love.physics.newBody(world, 300, 550)
  --objects.ground.shape = love.physics.newRectangleShape(2000,20)
  objects.ground.shape = love.physics.newChainShape(false, unpack(grpoints))
  objects.ground.fixture = love.physics.newFixture(objects.ground.body, objects.ground.shape)
  objects.ground.fixture:setDensity(0)
  objects.ground.fixture:setRestitution(0)
  --objects.ground.fixture:setFriction(3)
   
  
  -- Body of the car; a rectangle
  objects.carbody = {}
  objects.carbody.body = love.physics.newBody(world, 300, 500, "dynamic")
  objects.carbody.body:setInertia(500)
  objects.carbody.body:setMass(20)
  objects.carbody.shape = love.physics.newRectangleShape(100,40)
  objects.carbody.fixture = love.physics.newFixture(objects.carbody.body, objects.carbody.shape)  
  objects.carbody.fixture:setFriction(3)
  objects.carbody.fixture:setDensity(5)
  objects.carbody.fixture:setRestitution(0.3)  
 
  -- First wheel
  objects.wheel = {}
  objects.wheel.body = love.physics.newBody(world, 340, 520, "dynamic")
  objects.wheel.body:setInertia(50)
  objects.wheel.body:setMass(20)
  objects.wheel.shape = love.physics.newCircleShape(20)
  objects.wheel.fixture = love.physics.newFixture(objects.wheel.body, objects.wheel.shape)
  objects.wheel.fixture:setFriction(3)
  objects.wheel.fixture:setDensity(1)
  objects.wheel.fixture:setRestitution(0.1)
  
  -- Second wheel
  objects.wheel2 = {}
  objects.wheel2.body = love.physics.newBody(world, 260, 520, "dynamic")
  objects.wheel2.body:setInertia(50)
  objects.wheel2.body:setMass(20)
  objects.wheel2.shape = love.physics.newCircleShape(20)
  objects.wheel2.fixture = love.physics.newFixture(objects.wheel2.body, objects.wheel2.shape)
  objects.wheel2.fixture:setFriction(3)
  objects.wheel2.fixture:setDensity(1)
  objects.wheel2.fixture:setRestitution(0.1)
  
  -- Create joint between car body and first wheel
  objects.carbody.wheeljoint1 = love.physics.newRevoluteJoint(objects.wheel.body, objects.carbody.body, 340, 520)
  objects.carbody.wheeljoint1:enableMotor(true) 
  objects.carbody.wheeljoint1:setMaxMotorTorque(1000)
 
  -- Create joint between car body and second wheel
  objects.carbody.wheeljoint2 = love.physics.newRevoluteJoint(objects.wheel2.body, objects.carbody.body, 260, 520)
  objects.carbody.wheeljoint2:enableMotor(true) 
  objects.carbody.wheeljoint2:setMaxMotorTorque(1000)

end
 
function love.update(dt)
 
  if love.keyboard.isDown('right') then
     objects.motorspeed = objects.motorspeed - 2000 * dt
  end  
  if love.keyboard.isDown('left') then
     objects.motorspeed = objects.motorspeed + 2000 * dt
  end    
  if love.keyboard.isDown('down') then
     objects.motorspeed = 0
  end    
  
  objects.carbody.wheeljoint1:setMotorSpeed(objects.motorspeed)
  objects.carbody.wheeljoint2:setMotorSpeed(objects.motorspeed)
  
  world:update(dt)
  
end

 
function love.draw()
  
  -- Print speed
--  love.graphics.setColor(255,255,255)
--  local xvel, yvel = objects.carbody.body:getLinearVelocity()
--  local speed = math.floor(xvel)
--  love.graphics.print("Speed: " .. speed, 10, 10)
  
  -- Set view to center of car
  love.graphics.translate(objects.carbody.body:getX() * -1 + (windim.width / 2), 
    objects.carbody.body:getY() * -1 + (windim.height / 2))
  --love.graphics.scale(0.5, 0.5)
 
  -- Render ground
  love.graphics.setColor(72, 160, 14)
  love.graphics.line(objects.ground.body:getWorldPoints(objects.ground.shape:getPoints()))
  --love.graphics.polygon("fill", objects.ground.body:getWorldPoints(objects.ground.shape:getPoints()))
 
  -- Render car body
  love.graphics.setColor(72, 160, 200)
  love.graphics.polygon("fill", objects.carbody.body:getWorldPoints(objects.carbody.shape:getPoints()))  

  -- Render wheels
  love.graphics.setColor(193, 47, 14)
  love.graphics.circle("line", objects.wheel.body:getX(), objects.wheel.body:getY(), objects.wheel.shape:getRadius())   
  love.graphics.circle("line", objects.wheel2.body:getX(), objects.wheel2.body:getY(), objects.wheel2.shape:getRadius())  
  
  -- Render world boundary
  love.graphics.setColor(255,255,255)
  love.graphics.line(objects.boundary.body:getWorldPoints(objects.boundary.shape:getPoints()))
end
